<div id="top">

<div align="left" style="position: relative; width: 100%; height: 100%; ">

<!-- <img src="https://img.shields.io/badge/Apache%20Airflow-00ADD8?style=flat&logo=apacheairflow&logoColor=white" alt="Apache Airflow"> -->
<!-- <img src="https://img.shields.io/badge/HasiCorp%20Nomad-00ADD8?style=flat&logo=nomad&logoColor=white" alt="Nomad"> -->



<!-- BADGES -->
<a href="https://www.apache.org/licenses/LICENSE-2.0.txt"><img src="https://img.shields.io/:license-Apache%202-blue.svg?style=flat&color=00ADD8" alt="license"></a>
<a href="https://github.com/juditnovak/airflow-provider-nomad/commits"><img src="https://img.shields.io/github/last-commit/juditnovak/airflow-provider-nomad?style=flat&logo=git&logoColor=white&color=00ADD8" alt="last-commit"></a>
<a href="https://github.com/juditnovak/airflow-provider-nomad/actions"> <img src="https://github.com/juditnovak/airflow-provider-nomad/actions/workflows/main.yaml/badge.svg" alt="build"> </a>
<a href="https://pypi.org/project/apache-airflow-providers-nomad/"> <img src="https://img.shields.io/pypi/v/apache-airflow-providers-nomad?style=flat&color=00ADD8" alt="versions"> </a>

# Airflow Nomad Provider

<a href="https://python.org"><img src="https://img.shields.io/badge/Python-3776AB.svg?style=flat&logo=Python&logoColor=white" alt="Python"></a>
<a href="https://docs.pydantic.dev/latest/"><img src="https://img.shields.io/badge/Pydantic-E92063.svg?style=flat&logo=Pydantic&logoColor=white" alt="Pydantic"></a>
<a href="https://www.sphinx-doc.org/"><img src="https://img.shields.io/badge/Sphinx-000000.svg?style=flat&logo=Sphinx&logoColor=white" alt="Sphinx"></a>
<a href="https://developer.hashicorp.com/nomad/docs/reference/hcl2"> <img src="https://img.shields.io/badge/HCL-006BB6.svg?style=flat&logo=HCL&logoColor=white" alt="HCL"></a>

</div>
</div>

<br>
<br>

Provider for HashiCorp [Nomad](https://developer.hashicorp.com/nomad) clusters running Apache [Airflow](https://airflow.apache.org/) tasks.

For all details see the project's Airflow-style [documentation](https://juditnovak.github.io/airflow-provider-nomad/)

<br>

---

***Note***: *This project is not part of the official [Apache Airflow](https://airflow.apache.org/) release.*

---
